# Generated by roxygen2: do not edit by hand

S3method(plot,stat_power_result)
S3method(plot,stat_samplesize_result)
S3method(print,quick_anova_result)
S3method(print,quick_chisq_result)
S3method(print,quick_cor_result)
S3method(print,quick_ttest_result)
S3method(print,stat_power_result)
S3method(print,stat_samplesize_result)
S3method(summary,quick_anova_result)
S3method(summary,quick_chisq_result)
S3method(summary,quick_cor_result)
S3method(summary,quick_ttest_result)
S3method(summary,stat_power_result)
S3method(summary,stat_samplesize_result)
export("%is%")
export("%map%")
export("%match%")
export("%nin%")
export("%p%")
export(any_void)
export(bio_palette_gallery)
export(check_pkg)
export(clear_palette_cache)
export(cols_with_void)
export(comb)
export(combine_logic)
export(compile_palettes)
export(convert_gene_id)
export(create_palette)
export(df2list)
export(download_batch)
export(download_gene_ref)
export(download_geo_data)
export(download_url)
export(drop_void)
export(file_info)
export(file_tree)
export(get_ext)
export(get_palette)
export(gmt2df)
export(gmt2list)
export(hex2rgb)
export(inst_pkg)
export(is_void)
export(list_palettes)
export(map_column)
export(palette_cache_info)
export(perm)
export(pkg_functions)
export(pkg_version)
export(plot_bar)
export(plot_density)
export(plot_forest)
export(plot_pie)
export(plot_venn)
export(preview_palette)
export(quick_anova)
export(quick_chisq)
export(quick_cor)
export(quick_ttest)
export(read_excel_flex)
export(read_table_flex)
export(reload_palette_cache)
export(remind)
export(remove_palette)
export(replace_void)
export(rgb2hex)
export(rows_with_void)
export(safe_execute)
export(scale_color_evanverse)
export(scale_colour_evanverse)
export(scale_fill_evanverse)
export(set_mirror)
export(stat_power)
export(stat_samplesize)
export(update_pkg)
export(view)
export(with_timer)
export(write_xlsx_flex)
importFrom(magrittr,"%>%")
importFrom(rlang,.data)
importFrom(rlang,syms)
importFrom(stats,complete.cases)
importFrom(stats,cor)
importFrom(stats,cor.test)
importFrom(stats,density)
importFrom(stats,dist)
importFrom(stats,hclust)
importFrom(stats,median)
importFrom(stats,p.adjust)
importFrom(stats,sd)
importFrom(stats,var)
importFrom(utils,head)
importFrom(utils,modifyList)
